Storage
=======

Persistent stores for graphs, synthesis results, and incremental updates.

.. automodule:: storage.graph_store
   :members:
   :show-inheritance:

.. automodule:: storage.sqlite_graph_store
   :members:
   :show-inheritance:

.. automodule:: storage.kuzu_graph_store
   :members:
   :show-inheritance:

.. automodule:: storage.synthesis_store
   :members:
   :show-inheritance:

.. automodule:: storage.incremental
   :members:
   :show-inheritance:
